#ifndef NT2_INCLUDE_CONSTANTS_PIO_2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_PIO_2_HPP_INCLUDED

#include <nt2/constant/include/constants/pio_2.hpp>

#endif
